# encoding: utf-8

require 'spec_helper'

describe Settings::Config do
  context 'Provider module' do

    context '#merge_storage' do
      it 'raises an ProviderNotRespond exception when provider does not respond to :load method' do
        expect do
          Settings::Config.create { merge_storage 'string_as_provider' }
        end.to raise_error Settings::Config::ProviderNotRespond
      end
    end # context '#merge_storage'

    context '#extract_sub_hash_from' do
      it 'raises an RootNotExist exception when provider can not extract a hash' do
        provider = Settings::ENV.load(param1: true, para2: false)
        expect do
          Settings::Config.create { merge_storage(provider, root: 'wrong/path') }
        end.to raise_error Settings::Provider::RootNotExist
      end
    end # context '#extract_sub_hash_from'

    context '#validate_and_extract_hash_from' do
      it 'raises an HashNotValid exception when provider getting empty hash' do
        expect do
          Settings::Config.create { merge_storage Settings::ENV.load({}) }
        end.to raise_error Settings::Config::HashNotValid
      end
    end # context '#validate_and_extract_hash_from'

  end # context '#provider'
end # describe Settings::Config
