# encoding: utf-8

require 'spec_helper'

describe Settings::Storage do
  let(:hsh_sample) do
    { nested_hsh: { param1: true, param2: false },
      param1: 42,
      param2: 15,
      predicate: true,
      'special_sample' => { 55 => 'good' } }
  end

  subject { described_class.new(hsh_sample) }

  describe 'Storage' do
    context 'after #create' do
      it 'registers hash key as predicate method for booleans' do
        expect(subject.predicate?).to be_truthy
      end

      it 'have a correct value assigned with registered method' do
        expect(subject.param1).to eql(42)
      end

      context '#[]' do
        it 'raises an ValueNotFound exception when argument for [] not valid' do
          expect { subject[:param42] }
            .to raise_error(Settings::Storage::ValueNotFound)
        end

        it 'gives value by access throw [] method' do
          expect(subject[:param2]).to eql(15)
        end

        it 'provides chain call throw [] method' do
          expect(subject[:nested_hsh][:param2]).to eql(false)
        end

        it 'allows to use numbers and strings as parameters' do
          expect(subject['special_sample'][55]).to eql('good')
        end
      end # context "#[]"

      context '#fill_in_storage' do
        it 'registers hash key as method' do
          expect(subject.send(:respond_to?, :param1)).to be_truthy
        end

        it 'registers a sub-storage for sub-hash' do
          expect(subject.nested_hsh).to be_an_instance_of(Settings::Storage)
        end
      end # context "#fill_in_storage"

      context '#method_missing' do
        it 'redirect message call to sub-storage' do
          expect(subject.nested_hsh.param1).to_not be_nil
        end
      end # context "#method_missing"

      context '#respond_to?' do
        it 'redirect response_to? message call to sub-storage' do
          expect(subject.send(:respond_to?, :nested_hsh)).to be_truthy
        end
      end # context 'respond_to?'
    end # context 'after #create'

  end # describe "Storage"
end # describe Settings::Storage
